Thanks for taking the time to contribute to `pyseobnr`! Please be advised that if you are
viewing this on `github.com`, that the mirror there is not monitored.

`pyseobnr` developer's team does not use `github.com` for their contributions. Instead, we use
the GitLab server at [LIGO](https://git.ligo.org/waveforms/software/pyseobnr). For code submissions, code reviews, and
bug reports:

* if you are member of LIGO, please send patches there instead,
* if not, please reach out to the developers by email and send patches or feature requests.

